@@ -287,3 +287,18 @@ class KxyLogger(Logger):
                     return False
                     
         return True
+
+class VirtualLogger():
+    def refresh_time(self):
+        pass
+    def info(self, msg, logCategory='default', *args, **kwargs):
+        pass
+    
+    def debug(self, msg, logCategory='default', *args, **kwargs):
+        pass
+    
+    def warning(self, msg, logCategory='default', *args, **kwargs):
+        pass
+    
+    def error(self, msg, logCategory='default', *args, **kwargs):
+        pass
\ No newline at end of file
