@@ -1,3 +1,8 @@
+from typing import Generic, TypeVar
+
+
+T = TypeVar("T")
+
 class Mapper:
     __mapper_relation = {}
     logger=None
@@ -10,7 +15,10 @@ class Mapper:
     @staticmethod
     def getservice(clsName,*arg,**agrs):
         return Mapper.__mapper_relation[clsName](*arg,**agrs)
-
+    @staticmethod
+    def getservice_by_contract(contract:T,*arg,**agrs)->T:
+        clsName=contract.__name__.replace("I","",1)
+        return Mapper.__mapper_relation[clsName](*arg,**agrs)
     @staticmethod
     def getclass(clsName):
         return Mapper.__mapper_relation[clsName]
\ No newline at end of file
