@@ -51,7 +51,9 @@ def create_logger(logLeve,appName,env,filename='log/app',file_type='log',backupC
             prev_time = last_log_time.get()
             duration = current_time - prev_time if prev_time > 0 else 0
             last_log_time.set(current_time)
-            
+            logCategory='default'
+            if hasattr(record,'logCategory'):
+                logCategory = record.logCategory
             # 构建日志记录的字典
             log_record = {
                 "appName":appName,
@@ -64,7 +66,7 @@ def create_logger(logLeve,appName,env,filename='log/app',file_type='log',backupC
                 "sessionId": record.session_id,
                 "userId":record.userid,
                 "seqId": record.seq,
-                "logCategory":record.logCategory,
+                "logCategory":logCategory,
                 "message": record.getMessage(),
                 "CreateTime": self.formatTime(record, self.datefmt),
                 "createdOn": int(time.time() * 1000),  # 添加 Unix 时间戳
@@ -73,9 +75,6 @@ def create_logger(logLeve,appName,env,filename='log/app',file_type='log',backupC
             # 将字典转换为 JSON 字符串
             return json.dumps(log_record, ensure_ascii=False)
         
-    logging.basicConfig(
-        level=logLeve
-    )
     _logger = logging.getLogger(appName)
     _logger.setLevel(logLeve)
     # 创建一个 RotatingFileHandler 对象
@@ -100,6 +99,11 @@ def create_logger(logLeve,appName,env,filename='log/app',file_type='log',backupC
     handler.setLevel(logLeve)
     handler.setFormatter(formatter)
     handler.addFilter(TraceIdFilter())
+    
+    logging.basicConfig(
+        level=logLeve,
+        handlers=[handler]
+    )
 
     _logger.addHandler(handler)
     logger = KxyLogger(_logger,filename,file_type)
